# scatterplot.py
# ------------
# By MWC Contributors
# Uses lots of helper functions in other modules to draw a scatter plot.

from turtle import *
from superturtle.movement import no_delay
import constants
from generate_data import generate_data
from ticks import get_tick_values
from plotting import (
    prepare_screen, 
    draw_x_axis, 
    draw_y_axis,
    draw_x_tick, 
    draw_y_tick,
    draw_point, 
)
from transform import (
    maximum, 
    minimum,
    bounds, 
    clamp,
    ratio, 
    scale,
    get_x_values,
    get_y_values,
)

def draw_scatterplot(data, size=5, color="black"):
    "Draws a scatter plot, showing the data"
    prepare_screen()
    draw_axes(data)
    draw_points(data, color, size)

"""I understood from instructions and 1st try how to draw_axes for both x and y values.
Oh, to use the PLOT.HEIGHT for y because it's the vertical."""

def draw_axes(data):
    "Draws the scatter plot's axes."
    draw_x_axis()
    x_values = get_x_values(data)
    xmin, xmax = bounds(x_values)
    ticks = get_tick_values(xmin, xmax)
    for tick in ticks:
        screen_x_position = scale(tick, xmin, xmax, 0, constants.PLOT_WIDTH)
        draw_x_tick(screen_x_position, tick)

    draw_y_axis()
    "Draws the scatter plot's axes."
    y_values = get_y_values(data)
    ymin, ymax = bounds(y_values)
    ticks = get_tick_values(ymin, ymax)
    for tick in ticks:
        screen_y_position = scale(tick, ymin, ymax, 0, constants.PLOT_HEIGHT)
        draw_y_tick(screen_y_position, tick)

def draw_points(data, color, size):
    "Draws the scatter plot's points."

    """THE PLAN
        Find the x-bounds and the y-bounds of the data. You'll need these for scaling.
            Can shorten by using: 
                xmin, xmax = bounds(get_x_values(data))
                ymin, ymax = bounds(get_y_values(data))
        For each point in the data
                for points in data:  or  for x, y in data:
            Get the x and y value from the point.
            Find the scaled x-position for the point.
            Find the scaled y-position for the point.
            Use draw_point(scaled_x, scaled_y, color, size) to draw the point."""
    
    x_values = get_x_values(data)
    xmin, xmax = bounds(x_values)
    y_values = get_y_values(data)
    ymin, ymax = bounds(y_values)
    for x, y in data:
        scaled_x = scale(x, xmin, xmax, 0, constants.PLOT_WIDTH)
        scaled_y = scale(y, ymin, ymax, 0, constants.PLOT_HEIGHT)
        draw_point(scaled_x, scaled_y, color, size)

with no_delay():
    data = generate_data(50, 10, 500, 5, 400, 1000)
    draw_scatterplot(data, size=5, color="blue")
    hideturtle()
done()
